import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:flutter_gen/gen_l10n/app_localizations.dart';
import 'package:gui_app/const/colors.dart';
import 'package:gui_app/const/config.dart';
import 'package:gui_app/const/dimens.dart';
import 'package:gui_app/provider.dart';
import 'dart:async';

class EnergyBox extends ConsumerStatefulWidget {
  final double width;
  final double height;
  const EnergyBox(
      {Key? key, this.width = double.infinity, this.height = double.infinity})
      : super(key: key);
  @override
  ConsumerState<EnergyBox> createState() {
    return _EnergyState();
  }
}

class _EnergyState extends ConsumerState<EnergyBox> {
  _textAndNumberBox(
      {required String title, required int data, Color? valueColor}) {
    final Size containerSize = MediaQuery.of(context).size;
    final formatter = NumberFormat("#,###");
    final dataString = formatter.format(data).toString();
    return Container(
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(10),
        border: Border.all(color: energyBorderColor),
      ),
      width: widget.width,
      height: widget.height,
      child: Column(
        children: [
          Container(
            alignment: Alignment.bottomCenter,
            height: containerSize.height * 0.04,
            child: Text(
              title,
              style: TextStyle(
                  fontSize: containerSize.width * energyTitleFontSizeRatio,
                  color: textColor),
              textAlign: TextAlign.left,
            ),
          ),
          Container(
            height: containerSize.height * 0.05,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              crossAxisAlignment: CrossAxisAlignment.baseline,
              textBaseline: TextBaseline.alphabetic,
              children: [
                Text(
                  dataString,
                  style: TextStyle(
                    fontSize: containerSize.width * energyValueFontSizeRatio,
                    color: valueColor,
                  ),
                ),
                Text(
                  "MW",
                  style: TextStyle(
                    fontSize: containerSize.width * energyUnitFontSizeRatio,
                    color: valueColor,
                  ),
                )
              ],
            ),
          )
        ],
      ),
    );
  }

  @override
  void initState() {
    Timer.periodic(const Duration(seconds: 1), (Timer timer) {
      ref.read(timerProvider.notifier).state++;
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Column(children: [
      Row(mainAxisAlignment: MainAxisAlignment.spaceAround, children: [
        Expanded(
            child: _textAndNumberBox(
                title: L10n.of(context)!.totalCapacity,
                data: totalCapacityData,
                valueColor: textColor)),
        const Padding(padding: EdgeInsets.only(right: 20)),
        Expanded(
            child: _textAndNumberBox(
                title: L10n.of(context)!.target,
                data: ref.watch(targetProvider).toInt(),
                valueColor: textColor)),
        const Padding(padding: EdgeInsets.only(right: 20)),
        Expanded(
            child: _textAndNumberBox(
                title: L10n.of(context)!.energyGenerated,
                data: ref.watch(energyGeneratedProvider),
                valueColor: energyGenerateTextColor))
      ])
    ]);
  }
}
