import 'package:gui_app/provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_gen/gen_l10n/app_localizations.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:audioplayers/audioplayers.dart';
import 'package:gui_app/const/colors.dart';
import 'package:gui_app/const/dimens.dart';

class RunAlert extends ConsumerStatefulWidget {
  final double width;
  final double height;
  const RunAlert(
      {Key? key, this.width = double.infinity, this.height = double.infinity})
      : super(key: key);
  @override
  ConsumerState<RunAlert> createState() {
    return _RunAlertState();
  }
}

class _RunAlertState extends ConsumerState<RunAlert> {
  _fillBox({
    required String text,
    required Color fillColor,
  }) {
    final Size containerSize = MediaQuery.of(context).size;
    return Expanded(
        child: Container(
      decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(10),
          border: Border.all(color: runAlertBorderColor),
          color: fillColor),
      alignment: Alignment.center,
      child: Text(
        text,
        style: TextStyle(
            fontSize: containerSize.width * runAlertFontSizeRatio,
            color: textColor),
      ),
    ));
  }

  final AudioPlayer _audioPlayer = AudioPlayer();

  @override
  void initState() {
    _audioPlayer.setSourceAsset('sound/alarm.wav');
    _audioPlayer.setVolume(0.5);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    Color col = ref.watch(alertBlinkingProvider);
    if (col == alertBackgroundColor) {
      _audioPlayer.resume();
    }
    return Container(
        width: widget.width,
        height: widget.height,
        child: Row(
          children: [
            _fillBox(
                text: L10n.of(context)!.running, fillColor: runBackgroundColor),
            Padding(padding: EdgeInsets.only(right: 10)),
            _fillBox(
                text: L10n.of(context)!.alert,
                fillColor: col),
          ],
        ));
  }
}
